@@ -246,6 +246,12 @@ void GameArea::RebuildGameBackground()
   gameBackground=Lum::OS::driver->CreateBitmap(sokoban.GetWidth()*GetBoxSize(),
                                                sokoban.GetHeight()*GetBoxSize());
 
+  Lum::OS::FillRef fill=Lum::OS::display->GetFill(Lum::OS::Display::backgroundFillIndex);
+
+  fill->Draw(gameBackground->GetDrawInfo(),
+             0,0,sokoban.GetWidth()*GetBoxSize(),sokoban.GetWidth()*GetBoxSize(),
+             0,0,sokoban.GetWidth()*GetBoxSize(),sokoban.GetWidth()*GetBoxSize());
+
   game=Lum::OS::driver->CreateBitmap(sokoban.GetWidth()*GetBoxSize(),
                                      sokoban.GetHeight()*GetBoxSize());
 
@@ -283,13 +289,6 @@ void GameArea::RebuildGameBackground()
           DrawFloorInternal(gameBackground->GetDrawInfo(),cx*GetBoxSize(),cy*GetBoxSize(),GetBoxSize());
         }
       }
-      else {
-        Lum::OS::FillRef fill=Lum::OS::display->GetFill(Lum::OS::Display::backgroundFillIndex);
-
-        fill->Draw(gameBackground->GetDrawInfo(),
-                   cx*GetBoxSize(),cy*GetBoxSize(),GetBoxSize(),GetBoxSize(),
-                   cx*GetBoxSize(),cy*GetBoxSize(),GetBoxSize(),GetBoxSize());
-      }
     }
   }
 }
