@@ -67,9 +67,9 @@ public:
         return L"finished";
       }
       else {
-        return Lum::Base::NumberToWString(collection->GetCurrent()+1)+
+        return Lum::Base::NumberToWString((*iter)->GetCurrent()+1)+
                L"/"+
-               Lum::Base::NumberToWString(collection->GetLevelCount());
+               Lum::Base::NumberToWString((*iter)->GetLevelCount());
       }
     default:
       assert(false);
@@ -110,11 +110,11 @@ public:
 
     panel=Lum::VPanel::Create(true,true);
     panel->SetWidth(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
-    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
+    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*70)/100);
 
     headerModel=new Lum::Model::HeaderImpl();
-    headerModel->AddColumn(L"Collection",Lum::Base::Size::stdCharWidth,25);
-    headerModel->AddColumn(L"Current level",Lum::Base::Size::stdCharWidth,13);
+    headerModel->AddColumn(L"Collection",Lum::Base::Size::stdCharWidth,25,true);
+    headerModel->AddColumn(L"Current level",Lum::Base::Size::stdCharWidth,10);
 
     table=new Lum::Table();
     table->SetFlex(true,true);
@@ -123,6 +123,7 @@ public:
     table->SetHeaderModel(headerModel);
     table->SetSelection(selection);
     table->SetDoubleClickAction(okAction);
+    table->GetTableView()->SetAutoFitColumns(true);
     panel->Add(table);
 
     return panel;
@@ -196,7 +197,7 @@ public:
 
     panel=Lum::VPanel::Create(true,true);
     panel->SetWidth(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
-    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
+    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*70)/100);
 
     table=new Lum::Table();
     table->SetFlex(true,true);
@@ -294,11 +295,11 @@ public:
 
     panel=Lum::VPanel::Create(true,true);
     panel->SetWidth(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
-    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
+    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*70)/100);
 
     headerModel=new Lum::Model::HeaderImpl();
-    headerModel->AddColumn(L"Theme name",Lum::Base::Size::stdCharWidth,25);
-    headerModel->AddColumn(L"box size",Lum::Base::Size::stdCharWidth,13);
+    headerModel->AddColumn(L"Theme name",Lum::Base::Size::stdCharWidth,25,true);
+    headerModel->AddColumn(L"box size",Lum::Base::Size::stdCharWidth,8);
 
     table=new Lum::Table();
     table->SetFlex(true,true);
@@ -307,6 +308,7 @@ public:
     table->SetHeaderModel(headerModel);
     table->SetSelection(selection);
     table->SetDoubleClickAction(okAction);
+    table->GetTableView()->SetAutoFitColumns(true);
     panel->Add(table);
 
     return panel;
@@ -391,11 +393,10 @@ public:
 
   void PreInit()
   {
-    Lum::Label       *label;
-    Lum::Panel       *horiz;
-    Lum::Panel       *horiz2;
-    Lum::Panel       *vert;
-    Lum::TextValue   *textValue;
+    Lum::Label     *label;
+    Lum::Panel     *horiz;
+    Lum::Panel     *vert;
+    Lum::TextValue *textValue;
 
     horiz=Lum::HPanel::Create(true,true);
 
@@ -412,17 +413,13 @@ public:
 
     label=Lum::Label::Create();
 
-    horiz2=Lum::HPanel::Create(true,false);
-
     textValue=new Lum::TextValue();
     textValue->SetFlex(true,false);
+    textValue->SetAlignment(Lum::TextValue::right);
     textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
     textValue->SetModel(levelName);
-    horiz2->Add(textValue);
 
-    horiz2->Add(Lum::Button::Create(L"...",levelAction));
-
-    label->AddLabel(L"Level:",horiz2);
+    label->AddLabel(L"Level:",textValue);
 
     /*
     textValue=new Lum::TextValue();
@@ -436,7 +433,6 @@ public:
     textValue->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
     textValue->SetModel(pushes);
     label->AddLabel(L"Pushes:",textValue);*/
-    label->AddLabel(L"Finished:",new Lum::LED(gameArea->GetFinishedModel()));
 
     vert->Add(label);
     vert->AddSpace();
@@ -608,13 +604,21 @@ public:
     else if (model==aboutAction && aboutAction->IsFinished()) {
       Lum::Dlg::About::Show(this,info);
     }
-    else if (model==gameArea->GetFinishedModel() && gameArea->GetFinishedModel()->Get()) {
+    else if (model==gameArea->GetFinishedModel() &&
+             gameArea->GetFinishedModel()->Get()) {
       if (collection->GetCurrent()<level+1) {
         collection->SetCurrent(level+1);
       }
+
       if (!collection->IsFinished()) {
         SetLevel(level+1);
       }
+      else {
+        Lum::Dlg::Msg::ShowOk(this,
+                              L"Finished collection!",
+                              L"Congratulations!\n"
+                              L"You have finished this collection!");
+      }
     }
 
     Dialog::Resync(model,msg);
